vsutillib.files package
=======================

The ``ConfigurationSettings`` class
-----------------------------------

.. autoclass:: vsutillib.files.ConfigurationSettings
    :members:

The ``findFileInPath`` function
-------------------------------

.. autofunction:: vsutillib.files.findFileInPath

The ``getExecutable`` function
------------------------------

.. autofunction:: vsutillib.files.getExecutable

The ``getFileList`` function
----------------------------
.. autofunction:: vsutillib.files.getFileList
